@@ -3,7 +3,7 @@
 #   Dispatcher service for systemd-networkd
 # Copyright(c) 2016 by wave++ "Yuri D'Elia" <wavexx@thregr.org>
 # Distributed under GPLv3+ (see COPYING) WITHOUT ANY WARRANTY.
-# Copyright(c) 2018 by craftyguy "Clayton Craft" <clayton@craftyguy.net>
+# Copyright(c) 2018-2020 by craftyguy "Clayton Craft" <clayton@craftyguy.net>
 # Distributed under GPLv3+ (see COPYING) WITHOUT ANY WARRANTY.
 
 
@@ -101,12 +101,17 @@ def get_networkctl_status(iface_name):
         logger.error('Failed to get interface "%s" status: %s', iface_name, e)
         return data
 
+    out = out.decode('utf-8', errors='replace')
     oldk = None
-    for line in out.split(b'\n')[1:-1]:
-        line = line.decode('utf-8', errors='replace')
-        k = line[:16].strip() or oldk
+    for line in out.split('\n')[1:-1]:
+        kv = line.split(': ', 1)
+        k = oldk if len(kv) == 1 else kv[0].strip()
+        v = kv[-1].strip()
+        if not v:
+            continue
+
         oldk = k
-        v = line[18:].strip()
+
         if k in SINGLETONS:
             data[k] = v
         else:
