@@ -66,7 +66,7 @@ def test_get_networkctl_status(mock_subprocess, monkeypatch,
 
     # check output
     mock_subprocess.side_effect = None
-    mock_subprocess.return_value = get_datafile('networkctl_status')
+    mock_subprocess.return_value = get_datafile('test_get_networkctl_status')
     assert (networkd_dispatcher.get_networkctl_status('wlan0') ==
             get_networkctl_status_out)
 
@@ -333,6 +333,7 @@ with patch.object(networkd_dispatcher.Dispatcher, "_interface_scan",
             monkeypatch.setattr(('networkd_dispatcher.Dispatcher'
                                  '.ifaces_by_name'), {'eth0': 1})
             caplog.clear()
+            caplog.set_level(logging.WARNING)
             self.dp.trigger_all()
             _, _, ex = caplog.record_tuples[0]
             assert ex == 'Error handling initial for interface 1'
